summaryrefslogtreecommitdiffstats
path: root/wp-settings.php
diff options
context:
space:
mode:
Diffstat (limited to 'wp-settings.php')
-rw-r--r--wp-settings.php142
1 files changed, 100 insertions, 42 deletions
diff --git a/wp-settings.php b/wp-settings.php
index 724a1a6..11ca15f 100644
--- a/wp-settings.php
+++ b/wp-settings.php
@@ -100,7 +100,10 @@ if ( version_compare( '4.3', phpversion(), '>' ) ) {
die( 'Your server is running PHP version ' . phpversion() . ' but WordPress requires at least 4.3.' );
}
-if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
+if ( !defined('WP_CONTENT_DIR') )
+ define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' ); // no trailing slash, full paths only - WP_CONTENT_URL is defined further down
+
+if ( !extension_loaded('mysql') && !file_exists(WP_CONTENT_DIR . '/db.php') )
die( 'Your PHP installation appears to be missing the MySQL extension which is required by WordPress.' );
/**
@@ -166,7 +169,7 @@ if (defined('WP_DEBUG') and WP_DEBUG == true) {
// For an advanced caching plugin to use, static because you would only want one
if ( defined('WP_CACHE') )
- @include ABSPATH . 'wp-content/advanced-cache.php';
+ @include WP_CONTENT_DIR . '/advanced-cache.php';
/**
* Stores the location of the WordPress directory of functions, classes, and core content.
@@ -175,44 +178,52 @@ if ( defined('WP_CACHE') )
*/
define('WPINC', 'wp-includes');
-if ( !defined('LANGDIR') ) {
+if ( !defined('WP_LANG_DIR') ) {
/**
* Stores the location of the language directory. First looks for language folder in wp-content
* and uses that folder if it exists. Or it uses the "languages" folder in WPINC.
*
* @since 2.1.0
*/
- if ( file_exists(ABSPATH . 'wp-content/languages') && @is_dir(ABSPATH . 'wp-content/languages') )
- define('LANGDIR', 'wp-content/languages'); // no leading slash, no trailing slash
- else
- define('LANGDIR', WPINC . '/languages'); // no leading slash, no trailing slash
+ if ( file_exists(WP_CONTENT_DIR . '/languages') && @is_dir(WP_CONTENT_DIR . '/languages') ) {
+ define('WP_LANG_DIR', WP_CONTENT_DIR . '/languages'); // no leading slash, no trailing slash, full path, not relative to ABSPATH
+ if (!defined('LANGDIR')) {
+ // Old static relative path maintained for limited backwards compatibility - won't work in some cases
+ define('LANGDIR', 'wp-content/languages');
+ }
+ } else {
+ define('WP_LANG_DIR', ABSPATH . WPINC . '/languages'); // no leading slash, no trailing slash, full path, not relative to ABSPATH
+ if (!defined('LANGDIR')) {
+ // Old relative path maintained for backwards compatibility
+ define('LANGDIR', WPINC . '/languages');
+ }
+ }
}
-/**
- * Allows for the plugins directory to be moved from the default location.
- *
- * This isn't used everywhere. Constant is not used in plugin_basename()
- * which might cause conflicts with changing this.
- *
- * @since 2.1
- */
-if ( !defined('PLUGINDIR') )
- define('PLUGINDIR', 'wp-content/plugins'); // no leading slash, no trailing slash
-
require (ABSPATH . WPINC . '/compat.php');
require (ABSPATH . WPINC . '/functions.php');
+require (ABSPATH . WPINC . '/classes.php');
require_wp_db();
-$wpdb->set_prefix($table_prefix); // set up global tables
+
if ( !empty($wpdb->error) )
dead_db();
-if ( !defined( 'WP_INSTALLING' ) && file_exists(ABSPATH . 'wp-content/object-cache.php') )
- require_once (ABSPATH . 'wp-content/object-cache.php');
+$prefix = $wpdb->set_prefix($table_prefix); // set up global tables
+
+if ( is_wp_error($prefix) )
+ wp_die('<strong>ERROR</strong>: <code>$table_prefix</code> in <code>wp-config.php</code> can only contain numbers, letters, and underscores.');
+
+if ( file_exists(WP_CONTENT_DIR . '/object-cache.php') )
+ require_once (WP_CONTENT_DIR . '/object-cache.php');
else
require_once (ABSPATH . WPINC . '/cache.php');
wp_cache_init();
+if ( function_exists('wp_cache_add_global_groups') ) {
+ wp_cache_add_global_groups(array ('users', 'userlogins', 'usermeta', 'site-options', 'site-lookup', 'blog-lookup', 'blog-details', 'rss'));
+ wp_cache_add_non_persistent_groups(array( 'comment', 'counts', 'plugins' ));
+}
if( defined( 'SUNRISE' ) )
include_once( ABSPATH . 'wp-content/sunrise.php' );
@@ -224,15 +235,10 @@ $wpdb->set_prefix($table_prefix); // set up blog tables
$table_prefix = $table_prefix . $blog_id . '_';
wp_cache_init(); // need to init cache again after blog_id is set
-if ( defined('CUSTOM_USER_TABLE') )
- $wpdb->users = CUSTOM_USER_TABLE;
-if ( defined('CUSTOM_USER_META_TABLE') )
- $wpdb->usermeta = CUSTOM_USER_META_TABLE;
if( !defined( "UPLOADS" ) )
define( "UPLOADS", "wp-content/blogs.dir/{$wpdb->blogid}/files/" );
-require (ABSPATH . WPINC . '/classes.php');
require (ABSPATH . WPINC . '/plugin.php');
require (ABSPATH . WPINC . '/default-filters.php');
@@ -276,14 +282,34 @@ require (ABSPATH . WPINC . '/canonical.php');
require (ABSPATH . WPINC . '/shortcodes.php');
require (ABSPATH . WPINC . '/media.php');
+if ( !defined('WP_CONTENT_URL') )
+ define( 'WP_CONTENT_URL', get_option('siteurl') . '/wp-content'); // full url - WP_CONTENT_DIR is defined further up
+
require_once( ABSPATH . WPINC . '/wpmu-functions.php' );
-if( defined( "WP_INSTALLING" ) == false )
- $current_site->site_name = get_site_option('site_name');
+/**
+ * Allows for the plugins directory to be moved from the default location.
+ *
+ * @since 2.6
+ */
+if ( !defined('WP_PLUGIN_DIR') )
+ define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' ); // full path, no trailing slash
+if ( !defined('WP_PLUGIN_URL') )
+ define( 'WP_PLUGIN_URL', WP_CONTENT_URL . '/plugins' ); // full url, no trailing slash
+if ( !defined('PLUGINDIR') )
+ define( 'PLUGINDIR', 'wp-content/plugins' ); // Relative to ABSPATH. For back compat.
-if( $current_site->site_name == false ) {
+$current_site->site_name = get_site_option('site_name');
+if( $current_site->site_name == false )
$current_site->site_name = ucfirst( $current_site->domain );
-}
+
+// Used to guarantee unique hash cookies
+$cookiehash = '';
+/**
+ * Used to guarantee unique hash cookies
+ * @since 1.5
+ */
+define('COOKIEHASH', '' );
if( defined('WP_INSTALLING') == false ) {
$locale = get_option('WPLANG');
@@ -318,8 +344,6 @@ if( $current_blog->archived == '1' )
if( $current_blog->spam == '1' )
graceful_fail(__('This blog has been archived or suspended.'));
-define('COOKIEHASH', '');
-
/**
* Should be exactly the same as the default value of SECRET_KEY in wp-config-sample.php
* @since 2.5
@@ -331,21 +355,35 @@ $wp_default_secret_key = 'put your unique phrase here';
* @since 2.0.0
*/
if ( !defined('USER_COOKIE') )
- define('USER_COOKIE', 'wordpressuser');
+ define('USER_COOKIE', 'wordpressuser_' . COOKIEHASH);
/**
* It is possible to define this in wp-config.php
* @since 2.0.0
*/
if ( !defined('PASS_COOKIE') )
- define('PASS_COOKIE', 'wordpresspass');
+ define('PASS_COOKIE', 'wordpresspass_' . COOKIEHASH);
/**
* It is possible to define this in wp-config.php
* @since 2.5
*/
if ( !defined('AUTH_COOKIE') )
- define('AUTH_COOKIE', 'wordpress');
+ define('AUTH_COOKIE', 'wordpress_' . COOKIEHASH);
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('SECURE_AUTH_COOKIE') )
+ define('SECURE_AUTH_COOKIE', 'wordpress_sec_' . COOKIEHASH);
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('LOGGED_IN_COOKIE') )
+ define('LOGGED_IN_COOKIE', 'wordpress_logged_in_' . COOKIEHASH);
/**
* It is possible to define this in wp-config.php
@@ -374,7 +412,23 @@ if ( !defined('SITECOOKIEPATH') )
*/
if ( !defined('COOKIE_DOMAIN') )
define('COOKIE_DOMAIN', '.' . $current_site->domain);
-
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('FORCE_SSL_ADMIN') )
+ define('FORCE_SSL_ADMIN', false);
+force_ssl_admin(FORCE_SSL_ADMIN);
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.6
+ */
+if ( !defined('FORCE_SSL_LOGIN') )
+ define('FORCE_SSL_LOGIN', false);
+force_ssl_login(FORCE_SSL_LOGIN);
+
/**
* It is possible to define this in wp-config.php
* @since 2.5.0
@@ -385,15 +439,13 @@ if ( !defined( 'AUTOSAVE_INTERVAL' ) )
require (ABSPATH . WPINC . '/vars.php');
-if ( !defined('PLUGINDIR') )
- define('PLUGINDIR', 'wp-content/plugins'); // no leading slash, no trailing slash
if ( get_option('active_plugins') ) {
$current_plugins = get_option('active_plugins');
if ( is_array($current_plugins) ) {
foreach ($current_plugins as $plugin) {
- if ('' != $plugin && file_exists(ABSPATH . PLUGINDIR . '/' . $plugin))
- include_once(ABSPATH . PLUGINDIR . '/' . $plugin);
+ if ('' != $plugin && file_exists(WP_PLUGIN_DIR . '/' . $plugin))
+ include_once(WP_PLUGIN_DIR . '/' . $plugin);
}
}
}
@@ -415,6 +467,11 @@ if ( defined('WP_CACHE') && function_exists('wp_cache_postload') )
do_action('plugins_loaded');
+$default_constants = array( 'WP_POST_REVISIONS' => true );
+foreach ( $default_constants as $c => $v )
+ @define( $c, $v ); // will fail if the constant is already defined
+unset($default_constants, $c, $v);
+
// If already slashed, strip.
if ( get_magic_quotes_gpc() ) {
$_GET = stripslashes_deep($_GET );
@@ -459,6 +516,7 @@ $wp_rewrite =& new WP_Rewrite();
*/
$wp =& new WP();
+do_action('setup_theme');
/**
* Web Path to the current active template directory
@@ -480,7 +538,7 @@ load_default_textdomain();
* @since 1.5.0
*/
$locale = get_locale();
-$locale_file = ABSPATH . LANGDIR . "/$locale.php";
+$locale_file = WP_LANG_DIR . "/$locale.php";
if ( is_readable($locale_file) )
require_once($locale_file);
@@ -175,44 +178,52 @@ if ( defined('WP_CACHE') )
/**
- * Stores the location of the language directory. First looks for language folder in wp-content
+ * Stores the location of the language directory. First looks for language folder in WP_CONTENT_DIR
* and uses that folder if it exists. Or it uses the "languages" folder in WPINC.
*